"""
    QuaO Project request.py Copyright © CITYNOW Co. Ltd. All rights reserved.
"""
from ...data.callback.callback_url import CallbackUrl


class Request:
    def __init__(self, request_data):
        self.provider_job_id = request_data.get("providerJobId")
        self.user_token = request_data.get("userToken")
        self.user_identity = request_data.get("userIdentity")
        self.analysis = CallbackUrl(request_data.get("analysis"))
        self.finalization = CallbackUrl(request_data.get("finalization"))



from ..enum.invocation_step import InvocationStep
from ..enum.status.job_status import JobStatus
from ..enum.status.status_code import StatusCode


class StatusCodeMappingUtils:
    status_code_mapping = {
        JobStatus.ERROR: StatusCode.ERROR,
        JobStatus.DONE: StatusCode.DONE,
        JobStatus.COMPLETED: StatusCode.DONE,
        InvocationStep.PREPARATION: StatusCode.DONE,
        InvocationStep.POLLING: StatusCode.POLLING,
        InvocationStep.PROMISE: StatusCode.PROMISE,
        InvocationStep.ANALYSIS: StatusCode.DONE,
        InvocationStep.EXECUTION: StatusCode.DONE,
        InvocationStep.FINALIZATION: StatusCode.DONE
    }

    @staticmethod
    def resolve_status_code(key):
        result = StatusCodeMappingUtils.status_code_mapping.get(key)

        if result is None:
            return StatusCode.POLLING

        return result
